diff --git a/include/asterisk/res_hep.h b/include/asterisk/res_hep.h
index bd0129e..cfd213a 100644
--- a/include/asterisk/res_hep.h
+++ b/include/asterisk/res_hep.h
@@ -118,6 +118,14 @@ int hepv3_send_packet(struct hepv3_capture_info *capture_info);
  */
 enum hep_uuid_type hepv3_get_uuid_type(void);
 
+/*!
+ * \brief Return whether or not we're currently loaded and active
+ *
+ * \retval 0 The module is not loaded
+ * \retval 1 The module is loaded
+ */
+int hepv3_is_loaded(void);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
diff --git a/res/res_hep.c b/res/res_hep.c
index 723b27d..15e7790 100644
--- a/res/res_hep.c
+++ b/res/res_hep.c
@@ -409,9 +409,21 @@ enum hep_uuid_type hepv3_get_uuid_type(void)
 {
 	RAII_VAR(struct module_config *, config, ao2_global_obj_ref(global_config), ao2_cleanup);
 
+	if (!config) {
+		/* Well, that's unfortunate. Return something. */
+		return HEP_UUID_TYPE_CALL_ID;
+	}
+
 	return config->general->uuid_type;
 }
 
+int hepv3_is_loaded(void)
+{
+	RAII_VAR(struct module_config *, config, ao2_global_obj_ref(global_config), ao2_cleanup);
+
+	return (config != NULL) ? 1 : 0;
+}
+
 struct hepv3_capture_info *hepv3_create_capture_info(const void *payload, size_t len)
 {
 	struct hepv3_capture_info *info;
diff --git a/res/res_hep.exports.in b/res/res_hep.exports.in
index df0f2b4..e318ac9 100644
--- a/res/res_hep.exports.in
+++ b/res/res_hep.exports.in
@@ -3,6 +3,7 @@
 		LINKER_SYMBOL_PREFIX*hepv3_send_packet;
 		LINKER_SYMBOL_PREFIX*hepv3_create_capture_info;
 		LINKER_SYMBOL_PREFIX*hepv3_get_uuid_type;
+		LINKER_SYMBOL_PREFIX*hepv3_is_loaded;
 	local:
 		*;
 };
diff --git a/res/res_hep_pjsip.c b/res/res_hep_pjsip.c
index 936db93..8f5baa2 100644
--- a/res/res_hep_pjsip.c
+++ b/res/res_hep_pjsip.c
@@ -210,6 +210,11 @@ static int load_module(void)
 {
 	CHECK_PJSIP_MODULE_LOADED();
 
+	if (!ast_module_check("res_hep.so") || !hepv3_is_loaded()) {
+		ast_log(AST_LOG_WARNING, "res_hep is not loaded or running; declining module load\n");
+		return AST_MODULE_LOAD_DECLINE;
+	}
+
 	ast_sip_register_service(&logging_module);
 	return AST_MODULE_LOAD_SUCCESS;
 }
diff --git a/res/res_hep_rtcp.c b/res/res_hep_rtcp.c
index 49a9253..d77b19c 100644
--- a/res/res_hep_rtcp.c
+++ b/res/res_hep_rtcp.c
@@ -149,6 +149,10 @@ static void rtp_topic_handler(void *data, struct stasis_subscription *sub, struc
 
 static int load_module(void)
 {
+	if (!ast_module_check("res_hep.so") || !hepv3_is_loaded()) {
+		ast_log(AST_LOG_WARNING, "res_hep is not loaded or running; declining module load\n");
+		return AST_MODULE_LOAD_DECLINE;
+	}
 
 	stasis_rtp_subscription = stasis_subscribe(ast_rtp_topic(),
 		rtp_topic_handler, NULL);
